server {
        listen 80;
        listen [::]:80;
        location / {
                proxy_pass  http://docksible_redmine:3000;
                proxy_set_header Host      $host;
                proxy_set_header X-Real-IP $remote_addr;
        }

        server_name {{ ansible_host }};
        location ~ /.well-known/ {
                allow all;
		root /var/www/html;
        }
}

